/*
 *  Copyright (C) 2017, Texas Instruments Incorporated, All Rights Reserved
 *  SPDX-License-Identifier: Apache-2.0
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"); you may
 *  not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 *  WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
#include <stdint.h>
#include <sys/socket.h>
#include <mbedtls/net_sockets.h>

int net_send(void *ctx, const unsigned char *buf, size_t len)
{
    int ret;
    int fd;

    if (!ctx) {
        return (MBEDTLS_ERR_NET_INVALID_CONTEXT);
    }

    fd = *((int *) ctx);

    ret = send(fd, buf, len, 0);
    if (ret < 0) {
        if (errno == EAGAIN || errno == EWOULDBLOCK) {
            ret = MBEDTLS_ERR_SSL_WANT_WRITE;
        }
        else {
            ret = MBEDTLS_ERR_NET_SEND_FAILED;
        }
    }

    return (ret);
}

int net_recv(void *ctx, unsigned char *buf, size_t len)
{
    int ret;
    int fd;

    if (!ctx) {
        return (MBEDTLS_ERR_NET_INVALID_CONTEXT);
    }

    fd = *((int *) ctx);

    ret = recv(fd, buf, len, 0);
    if (ret < 0) {
        if (errno == EAGAIN || errno == EWOULDBLOCK) {
            ret = MBEDTLS_ERR_SSL_WANT_READ;
        }
        else {
            ret = MBEDTLS_ERR_NET_RECV_FAILED;
        }
    }

    return (ret);
}
